@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-02-15'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -137,10 +137,11 @@ from `Getopt::Long` specification. If you provide completion routine in
 
 Note that this routine does not use `Getopt::Long` (it does its own parsing) and
 currently is not affected by Getopt::Long's configuration. Its behavior mimics
-Getopt::Long under these configuration: `bundling`, `no_ignore_case`. Which I
-think is the sensible default. This routine also does not currently support
-`auto_help` and `auto_version`, so you'll need to add those options specifically
-if you want to recognize `--help/-?` and `--version`, respectively.
+Getopt::Long under these configuration: `no_ignore_case`, `bundling` (or
+`no_bundling` if the `bundling` option is turned off). Which I think is the
+sensible default. This routine also does not currently support `auto_help` and
+`auto_version`, so you'll need to add those options specifically if you want to
+recognize `--help/-?` and `--version`, respectively.
 
 _
     args => {
@@ -239,6 +240,24 @@ The keys from this `extras` hash will be merged into the final `%args` passed to
 completion routines. Note that standard keys like `type`, `word`, and so on as
 described in the function description will not be overwritten by this.
 
+_
+        },
+        bundling => {
+            schema  => 'bool*',
+            default => 1,
+            'summary.alt.bool.not' => 'Turn off bundling',
+            description => <<'_',
+
+If you turn off bundling, completion of short-letter options won't support
+bundling (e.g. `-b<tab>` won't add more single-letter options), but single-dash
+multiletter options can be recognized. Currently only those specified with a
+single dash will be completed. For example if you have `-foo=s` in your option
+specification, `-f<tab>` can complete it.
+
+This can be used to complete old-style programs, e.g. emacs which has options
+like `-nw`, `-nbc` etc (but also have double-dash options like
+`--no-window-system` or `--no-blinking-cursor`).
+
 _
         },
     },
@@ -269,6 +288,7 @@ sub complete_cli_arg {
     my $gospec = $args{getopt_spec} or die "Please specify getopt_spec";
     my $comp = $args{completion};
     my $extras = $args{extras} // {};
+    my $bundling = $args{bundling} // 1;
     my %parsed_opts;
 
     $log->tracef('[comp][compgl] entering %s(), words=%s, cword=%d, word=<%s>',
@@ -285,7 +305,9 @@ sub complete_cli_arg {
             my @o = $res->{is_neg} && length($o0) > 1 ?
                 ($o0, "no$o0", "no-$o0") : ($o0);
             for my $o (@o) {
-                my $k = length($o) > 1 ? "--$o" : "-$o";
+                my $k = length($o)==1 ||
+                    (!$bundling && $res->{dash_prefix} eq '-') ?
+                        "-$o" : "--$o";
                 $opts{$k} = {
                     name => $k,
                     ospec => $ospec, # key to getopt specification
@@ -326,6 +348,7 @@ sub complete_cli_arg {
             # split bundled short options
           SPLIT_BUNDLED:
             {
+                last unless $bundling;
                 my $shorts = $word;
                 if ($shorts =~ s/\A-([^-])(.*)/$2/) {
                     my $opt = "-$1";
@@ -370,7 +393,7 @@ sub complete_cli_arg {
             # split --foo=val -> --foo, =, val
           SPLIT_EQUAL:
             {
-                if ($word =~ /\A(--[^=]+)(=)(.*)/) {
+                if ($word =~ /\A(--?[^=]+)(=)(.*)/) {
                     splice @words, $i, 1, $1, $2, $3;
                     $word = $1;
                     $cword += 2 if $cword >= $i;
@@ -577,7 +600,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.28 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-01-03.
+This document describes version 0.29 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-02-15.
 
 =head1 SYNOPSIS
 
@@ -601,15 +624,28 @@ C<completion>, you can also complete I<option values> and I<arguments>.
 
 Note that this routine does not use C<Getopt::Long> (it does its own parsing) and
 currently is not affected by Getopt::Long's configuration. Its behavior mimics
-Getopt::Long under these configuration: C<bundling>, C<no_ignore_case>. Which I
-think is the sensible default. This routine also does not currently support
-C<auto_help> and C<auto_version>, so you'll need to add those options specifically
-if you want to recognize C<--help/-?> and C<--version>, respectively.
+Getopt::Long under these configuration: C<no_ignore_case>, C<bundling> (or
+C<no_bundling> if the C<bundling> option is turned off). Which I think is the
+sensible default. This routine also does not currently support C<auto_help> and
+C<auto_version>, so you'll need to add those options specifically if you want to
+recognize C<--help/-?> and C<--version>, respectively.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<bundling> => I<bool> (default: 1)
+
+If you turn off bundling, completion of short-letter options won't support
+bundling (e.g. C<< -bE<lt>tabE<gt> >> won't add more single-letter options), but single-dash
+multiletter options can be recognized. Currently only those specified with a
+single dash will be completed. For example if you have C<-foo=s> in your option
+specification, C<< -fE<lt>tabE<gt> >> can complete it.
+
+This can be used to complete old-style programs, e.g. emacs which has options
+like C<-nw>, C<-nbc> etc (but also have double-dash options like
+C<--no-window-system> or C<--no-blinking-cursor>).
+
 =item * B<completion> => I<code>
 
 Completion routine to complete option value/argument.
@@ -706,6 +742,7 @@ you're using bash).
 
 Return value:  (hash|array)
 
+
 You can use C<format_completion> function in C<Complete::Bash> module to format
 the result of this function for bash.
 
